@@ -20,14 +20,13 @@
 
 package org.videolan.libvlc;
 
-import java.util.ArrayList;
-
 import android.os.Build;
 import android.util.Log;
-import android.view.Surface;
 
 import org.videolan.libvlc.util.HWDecoderUtil;
 
+import java.util.ArrayList;
+
 @SuppressWarnings("unused, JniMissingFunction")
 public class LibVLC extends VLCObject<LibVLC.Event> {
     private static final String TAG = "VLC/LibVLC";
@@ -153,7 +152,6 @@ public class LibVLC extends VLCObject<LibVLC.Event> {
             return;
         sLoaded = true;
 
-        System.loadLibrary("compat.7");
         if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.GINGERBREAD_MR1) {
             try {
                 if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.HONEYCOMB_MR1)
@@ -188,6 +186,10 @@ public class LibVLC extends VLCObject<LibVLC.Event> {
             }
         }
 
+        try {
+            System.loadLibrary("compat.7");
+        } catch (Throwable ignored) {}
+
         try {
             System.loadLibrary("vlc");
             System.loadLibrary("vlcjni");
