@@ -124,7 +124,7 @@ public class AsyncImageLoader {
      * Custom bindings to trigger image (dwon)loading
      */
 
-    @BindingAdapter({"bind:imageUri", "bind:binding"})
+    @BindingAdapter({"imageUri", "binding"})
     public static void downloadIcon(final View v, final Uri imageUri, final ViewDataBinding vdb) {
         AsyncImageLoader.LoadImage(new Callbacks() {
             @Override
@@ -141,7 +141,7 @@ public class AsyncImageLoader {
     }
 
 
-    @BindingAdapter({"bind:mediaWithArt"})
+    @BindingAdapter({"mediaWithArt"})
     public static void downloadIcon(View v, MediaWrapper mw) {
         if (mw == null)
             return;
@@ -154,7 +154,7 @@ public class AsyncImageLoader {
 
     }
 
-    @BindingAdapter({"bind:media"})
+    @BindingAdapter({"media"})
     public static void loadPicture(ImageView v, MediaWrapper mw) {
         ViewDataBinding vdb = null;
         if (v.getTag() instanceof ViewDataBinding)
@@ -162,7 +162,7 @@ public class AsyncImageLoader {
         loadPicture(v, mw, vdb);
     }
 
-    @BindingAdapter({"bind:item"})
+    @BindingAdapter({"item"})
     public static void loadPicture(final ImageView v, final AudioBrowserListAdapter.ListItem item) {
         final Object tag = v.getTag();
         if (tag == null || !(tag instanceof ViewDataBinding))
@@ -190,7 +190,7 @@ public class AsyncImageLoader {
         }, v);
     }
 
-    @BindingAdapter({"bind:media", "bind:binding"})
+    @BindingAdapter({"media", "binding"})
     public static void loadPicture(ImageView v, MediaWrapper mw, ViewDataBinding vdb) {
         if (mw instanceof MediaGroup)
             mw = ((MediaGroup) mw).getFirstMedia();
