@@ -1,7 +1,6 @@
 package org.videolan.vlc.gui.video;
 
 import android.os.Message;
-import android.util.Log;
 
 import org.videolan.vlc.media.MediaLibrary;
 import org.videolan.vlc.media.MediaWrapper;
@@ -9,8 +8,6 @@ import org.videolan.vlc.interfaces.IVideoBrowser;
 import org.videolan.vlc.util.WeakHandler;
 
 public class VideoListHandler extends WeakHandler<IVideoBrowser> {
-    public static final int UPDATE_ITEM = 0;
-    public static final int MEDIA_ITEMS_UPDATED = 100;
 
     public VideoListHandler(IVideoBrowser owner) {
         super(owner);
@@ -22,11 +19,10 @@ public class VideoListHandler extends WeakHandler<IVideoBrowser> {
         if(owner == null) return;
 
         switch (msg.what) {
-            case UPDATE_ITEM:
+            case MediaLibrary.UPDATE_ITEM:
                 owner.updateItem((MediaWrapper)msg.obj);
                 break;
             case MediaLibrary.MEDIA_ITEMS_UPDATED:
-                Log.d("load", "MEDIA_ITEMS_UPDATED");
                 owner.updateList();
                 break;
         }
