@@ -35,6 +35,7 @@ import android.os.Message;
 import android.support.v7.app.AlertDialog;
 import android.support.v7.app.AppCompatActivity;
 import android.support.v7.preference.PreferenceManager;
+import android.text.TextUtils;
 import android.util.Log;
 import android.view.View;
 import android.view.WindowManager;
@@ -245,10 +246,10 @@ public class SubtitlesDownloader {
                             break;
                         resultMap = (HashMap<String, Object>) subtitleMaps[i];
                         srtFormat = (String) resultMap.get("SubFormat");
-                        Integer queryNumber = (Integer) resultMap.get("QueryNumber");
+                        String queryNumber = (String) resultMap.get("QueryNumber");
                         subLanguageID = (String) resultMap.get("SubLanguageID");
                         subDownloadLink = (String) resultMap.get("SubDownloadLink");
-                        fileUrl = (String) paths[queryNumber.intValue()/languages.size()];
+                        fileUrl = (String) paths[Integer.getInteger(queryNumber, 0).intValue()/languages.size()];
                         if (fileUrl == null) //we keep only result for exact matching name
                             continue;
                         fileName = fileUrl.substring(fileUrl.lastIndexOf('/') + 1);
@@ -379,7 +380,7 @@ public class SubtitlesDownloader {
                     index.put(hash, mediaUri.getPath());
                     video.put("moviehash", hash);
                     video.put("moviebytesize", String.valueOf(fileLength));
-                } else {
+                } else if (!TextUtils.isEmpty(tag)) {
                     video.put("tag", tag);
                     int dotPos = tag.lastIndexOf('.');
                     if (dotPos > -1)
